@@ -7,7 +7,7 @@ A simple twitch chat bot.\n
 Chat bots can join channels, listen to chat and reply to messages, commands, subscriptions and many more.
 
 .. warning::
-    Please note that the Chat Bot is currently in a **early alpha** stage!\n
+    Please note that the Chat Bot is currently in a **alpha** stage!\n
     Bugs and oddities are to be expected.\n
     Please report all feature requests and bug requests to the `github page <https://github.com/Teekeks/pyTwitchAPI/issues>`_.
 
@@ -270,7 +270,7 @@ from twitchAPI.types import ChatRoom, TwitchBackendException, AuthType, AuthScop
 
 from typing import List, Optional, Union, Callable, Dict, Awaitable, Any
 
-__all__ = ['ChatUser', 'EventData', 'ChatMessage', 'ChatCommand', 'ChatSub', 'Chat', 'ChatRoom', 'ChatEvent', 'RoomStateChangeEvent',
+__all__ = ['Chat', 'ChatUser', 'EventData', 'ChatMessage', 'ChatCommand', 'ChatSub', 'ChatRoom', 'ChatEvent', 'RoomStateChangeEvent',
            'JoinEvent', 'JoinedEvent', 'LeftEvent', 'ClearChatEvent', 'WhisperEvent', 'MessageDeletedEvent']
 
 
@@ -488,7 +488,7 @@ class ClearChatEvent(EventData):
         self.duration: Optional[int] = int(parsed['tags']['ban-duration']) if parsed['tags'].get('ban-duration') not in (None, '') else None
         """duration of the timeout in seconds. None if user was not timed out"""
         self.banned_user_id: Optional[str] = parsed['tags'].get('target-user-id')
-        """The ID of the user who got banned or timed out. if :const:`twitchAPI.chat.ClearChatEvent.duration` is None, the user was banned.
+        """The ID of the user who got banned or timed out. if :const:`~twitchAPI.chat.ClearChatEvent.duration` is None, the user was banned.
         Will be None when the user was not banned nor timed out."""
         self.sent_timestamp: int = int(parsed['tags'].get('tmi-sent-ts'))
         """The timestamp the event happend at"""
@@ -520,11 +520,16 @@ EVENT_CALLBACK_TYPE = Callable[[Any], Awaitable[None]]
 class Chat:
     """The chat bot instance"""
 
-    def __init__(self, twitch: Twitch, connection_url: Optional[str] = None, is_verified_bot: bool = False):
+    def __init__(self,
+                 twitch: Twitch,
+                 connection_url: Optional[str] = None,
+                 is_verified_bot: bool = False,
+                 initial_channel: Optional[List[str]] = None):
         """
         :param twitch: A Authenticated twitch instance
         :param connection_url: alternative connection url |default|:code:`None`
         :param is_verified_bot: set to true if your bot is verified by twitch |default|:code:`False`
+        :param initial_channel: List of channel which should be automatically joined on startup |default| :code:`None`
         """
         self.logger: Logger = getLogger('twitchAPI.chat')
         """The logger used for Chat related log messages"""
@@ -535,8 +540,11 @@ class Chat:
         self.connection_url: str = connection_url if connection_url is not None else TWITCH_CHAT_URL
         self.ping_frequency: int = 120
         self.ping_jitter: int = 4
+        self._initial_channel: Optional[List[str]] = initial_channel
         self.listen_confirm_timeout: int = 30
         self.reconnect_delay_steps: List[int] = [0, 1, 2, 4, 8, 16, 32, 64, 128]
+        self.log_no_registered_command_handler: bool = True
+        """Controls if instances of commands being issued in chat where no handler exists should be logged. |default|:code:`True`"""
         self.__connection = None
         self._session = None
         self.__socket_thread: threading.Thread = None
@@ -991,6 +999,10 @@ class Chat:
         self.logger.debug('got ready event')
         dat = EventData(self)
         self._ready = True
+        if self._initial_channel is not None and len(self._initial_channel) > 0:
+            _failed = await self.join_room(self._initial_channel)
+            if len(_failed) > 0:
+                self.logger.warning(f'failed to join the following channel of the initial following list: {", ".join(_failed)}')
         for h in self._event_handler.get(ChatEvent.READY, []):
             t = asyncio.ensure_future(h(dat))
             t.add_done_callback(self._task_callback)
@@ -1004,7 +1016,8 @@ class Chat:
                 t = asyncio.ensure_future(handler(ChatCommand(self, parsed)))
                 t.add_done_callback(self._task_callback)
             else:
-                self.logger.info(f'no handler registered for command "{command_name}"')
+                if self.log_no_registered_command_handler:
+                    self.logger.info(f'no handler registered for command "{command_name}"')
         handler = self._event_handler.get(ChatEvent.MESSAGE, [])
         message = ChatMessage(self, parsed)
         for h in handler:
@@ -1095,15 +1108,30 @@ class Chat:
     def is_mod(self, room: Union[str, ChatRoom]) -> bool:
         """Check if chat bot is a mod in a channel
 
-        :param room: The chat room you want to check if bot is a mod in without the #
-        :return: Returns if chat bot is user/mod """
+        :param room: The chat room you want to check if bot is a mod in.
+            This can either be a instance of :const:`~twitchAPI.types.ChatRoom` or a string with the room name (either with leading # or without)
+        :return: Returns True if chat bot is a mod """
         if isinstance(room, ChatRoom):
             room = room.name
         if room is None or len(room) == 0:
             raise ValueError('please specify a room')
         if room[0] == '#':
             room = room[1:]
-        return self._mod_status_cache.get(room, 'user') == 'mod'
+        return self._mod_status_cache.get(room.lower(), 'user') == 'mod'
+
+    def is_in_room(self, room: Union[str, ChatRoom]) -> bool:
+        """Check if the bot is currently in the given chat room
+
+        :param room: The chat room you want to check
+            This can either be a instance of :const:`~twitchAPI.types.ChatRoom` or a string with the room name (either with leading # or without)
+        """
+        if isinstance(room, ChatRoom):
+            room = room.name
+        if room is None or len(room) == 0:
+            raise ValueError('please specify a room')
+        if room[0] == '#':
+            room = room[1:]
+        return self.room_cache.get(room.lower()) is not None
 
     async def join_room(self, chat_rooms: Union[List[str], str]):
         """ join one or more chat rooms\n
@@ -1114,12 +1142,19 @@ class Chat:
         """
         if isinstance(chat_rooms, str):
             chat_rooms = [chat_rooms]
-        room_str = ','.join([f'#{c}' if c[0] != '#' else c for c in chat_rooms])
         target = [c[1:].lower() if c[0] == '#' else c.lower() for c in chat_rooms]
         for r in target:
             self._room_join_locks.append(r)
-        await self._join_bucket.put()
-        await self._send_message(f'JOIN {room_str}')
+        if len(target) > self._join_bucket.left():
+            # we want to join more than the current bucket has left, join slowly one after another
+            # TODO we could join the current remaining bucket size in blocks
+            for r in target:
+                await self._join_bucket.put()
+                await self._send_message(f'JOIN #{r}')
+        else:
+            # enough space in the current bucket left, join all at once
+            await self._join_bucket.put(len(target))
+            await self._send_message(f'JOIN {",".join([f"#{x}" for x in target])}')
         # wait for us to join all rooms
         timeout = datetime.datetime.now() + datetime.timedelta(seconds=self.join_timeout)
         while any([r in self._room_join_locks for r in target]) and timeout > datetime.datetime.now():
@@ -1165,7 +1200,7 @@ class Chat:
         if text is None or len(text) == 0:
             raise ValueError('you can\'t send a empty message')
         if room[0] != '#':
-            room = f'#{room}'
+            room = f'#{room}'.lower()
         bucket = self._get_message_bucket(room[1:])
         await bucket.put()
         await self._send_message(f'PRIVMSG {room} :{text}')
@@ -1177,7 +1212,7 @@ class Chat:
         :param chat_rooms: The room or rooms you want to leave"""
         if isinstance(chat_rooms, str):
             chat_rooms = [chat_rooms]
-        room_str = ','.join([f'#{c}' if c[0] != '#' else c for c in chat_rooms])
+        room_str = ','.join([f'#{c}'.lower() if c[0] != '#' else c.lower() for c in chat_rooms])
         target = [c[1:].lower() if c[0] == '#' else c.lower() for c in chat_rooms]
         for r in target:
             self._room_leave_locks.append(r)
